askbot.conf — Askbot 0.12.7 documentation

# Askbot Project Documentation

Home | Ask Questions | Consulting Services | Documentation | Contribute | Contact

# `askbot.conf`

## `Modules`

- askbot.conf.email

- askbot.conf.external_keys

- askbot.conf.flatpages

- askbot.conf.forum_data_rules

- askbot.conf.minimum_reputation

- askbot.conf.reputation_changes

- askbot.conf.settings_wrapper

- askbot.conf.site_settings

- askbot.conf.skin_counter_settings

- askbot.conf.skin_general_settings

- askbot.conf.user_settings

- askbot.conf.vote_rules